@@ -782,7 +782,7 @@ Object* Operations::reduceValueMatrix(Operator::OperatorType op, Cn* v, Matrix*
                 *correct=new QString(QCoreApplication::tr("Invalid index for a container"));
                 ret=new None();
             } else {
-                MatrixRow* row = static_cast<MatrixRow*>(m1->rows()[select-1]);
+                MatrixRow* row = static_cast<MatrixRow*>(m1->rows().at(select-1));
                 Vector* nv = new Vector(row->size());
                 for(Vector::iterator it=row->begin(); it!=row->end(); ++it) {
                     nv->appendBranch((*it));
@@ -1158,6 +1158,7 @@ Operations::UnaryOp Operations::opsUnary[] = {
 
 Object * Operations::reduceUnary(Operator::OperatorType op, Object * val, QString** correct)
 {
+    Q_ASSERT(val->type()<=Operator::matrix);
     UnaryOp f=opsUnary[val->type()];
     
     Q_ASSERT(f && "using reduceUnary in a wrong way");
